@@ -1,5 +1,6 @@
 /*
  * Copyright (C) 2009 Pierre-Luc Beaudoin <pierre-luc@pierlux.com>
+ * Copyright (C) 2010 Jiri Techet <techet@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -32,16 +33,27 @@
 
 G_BEGIN_DECLS
 
-#define CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY     (champlain_map_source_factory_get_type())
-#define CHAMPLAIN_MAP_SOURCE_FACTORY(obj)     (G_TYPE_CHECK_INSTANCE_CAST((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactory))
-#define CHAMPLAIN_MAP_SOURCE_FACTORY_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass),  CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryClass))
-#define CHAMPLAIN_IS_MAP_SOURCE_FACTORY(obj)  (G_TYPE_CHECK_INSTANCE_TYPE((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY))
-#define CHAMPLAIN_IS_MAP_SOURCE_FACTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass),  CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY))
-#define CHAMPLAIN_MAP_SOURCE_FACTORY_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj),  CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryClass))
+#define CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY champlain_map_source_factory_get_type ()
+
+#define CHAMPLAIN_MAP_SOURCE_FACTORY(obj) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactory))
+
+#define CHAMPLAIN_MAP_SOURCE_FACTORY_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_CAST ((klass), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryClass))
+
+#define CHAMPLAIN_IS_MAP_SOURCE_FACTORY(obj) \
+  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY))
+
+#define CHAMPLAIN_IS_MAP_SOURCE_FACTORY_CLASS(klass) \
+  (G_TYPE_CHECK_CLASS_TYPE ((klass), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY))
+
+#define CHAMPLAIN_MAP_SOURCE_FACTORY_GET_CLASS(obj) \
+  (G_TYPE_INSTANCE_GET_CLASS ((obj), CHAMPLAIN_TYPE_MAP_SOURCE_FACTORY, ChamplainMapSourceFactoryClass))
+
+typedef struct _ChamplainMapSourceFactoryPrivate ChamplainMapSourceFactoryPrivate;
 
 typedef struct _ChamplainMapSourceFactory ChamplainMapSourceFactory;
 typedef struct _ChamplainMapSourceFactoryClass ChamplainMapSourceFactoryClass;
-typedef struct _ChamplainMapSourceFactoryPrivate ChamplainMapSourceFactoryPrivate;
 
 struct _ChamplainMapSourceFactory
 {
@@ -56,19 +68,18 @@ struct _ChamplainMapSourceFactoryClass
 
 GType champlain_map_source_factory_get_type (void);
 
-ChamplainMapSourceFactory * champlain_map_source_factory_dup_default (void);
+ChamplainMapSourceFactory *champlain_map_source_factory_dup_default (void);
 
-GSList * champlain_map_source_factory_dup_list (ChamplainMapSourceFactory *factory);
-
-ChamplainMapSource * champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
+ChamplainMapSource *champlain_map_source_factory_create (ChamplainMapSourceFactory *factory,
     const gchar *id);
-ChamplainMapSource * champlain_map_source_factory_create_cached_source (ChamplainMapSourceFactory *factory,
+ChamplainMapSource *champlain_map_source_factory_create_cached_source (ChamplainMapSourceFactory *factory,
     const gchar *id);
+ChamplainMapSource *champlain_map_source_factory_create_error_source (ChamplainMapSourceFactory *factory,
+    guint tile_size);
 
-gboolean
-champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
-    ChamplainMapSourceDesc *desc, ChamplainMapSourceConstructor constructor,
-    gpointer data);
+gboolean champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
+    ChamplainMapSourceDesc *desc);
+GSList *champlain_map_source_factory_get_registered (ChamplainMapSourceFactory *factory);
 
 #ifndef CHAMPLAIN_HAS_MAEMO
 /**
@@ -83,6 +94,12 @@ champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
  * OpenStreetMap Osmarender
  */
 #define CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER "osm-osmarender"
+/**
+ * CHAMPLAIN_MAP_SOURCE_OSM_MAPQUEST:
+ *
+ * Mapquest OpenStreetMap
+ */
+#define CHAMPLAIN_MAP_SOURCE_OSM_MAPQUEST "osm-mapquest"
 /**
  * CHAMPLAIN_MAP_SOURCE_OSM_CYCLE_MAP:
  *
@@ -110,6 +127,7 @@ champlain_map_source_factory_register (ChamplainMapSourceFactory *factory,
 #else
 #define CHAMPLAIN_MAP_SOURCE_OSM_MAPNIK "OpenStreetMap I"
 #define CHAMPLAIN_MAP_SOURCE_OSM_OSMARENDER "OpenStreetMap II"
+#define CHAMPLAIN_MAP_SOURCE_OSM_MAPQUEST "Mapquest OSM"
 #define CHAMPLAIN_MAP_SOURCE_OSM_CYCLE_MAP "OpenCycleMap"
 #define CHAMPLAIN_MAP_SOURCE_OSM_TRANSPORT_MAP "Public Transport"
 #define CHAMPLAIN_MAP_SOURCE_OAM "OpenAerialMap"
